(*  GREATIS SYSTEM FONTS                                    *)
(*  Copyright (C) 2005-2014 Greatis Software                *)
(*                                                          *)
(*  http://www.greatis.com/delphicb/systemfonts/            *)

unit Main;

interface

uses
  Windows, Messages, SysUtils, Classes, Graphics, Controls, Forms, Dialogs,
  SystemFonts, StdCtrls, ShellAPI;

type
  TFormMain = class(TForm)
    SystemFonts: TSystemFonts;
    LabelCaptionFont: TLabel;
    LabelSmallCaptionFont: TLabel;
    LabelMenuFont: TLabel;
    LabelStatusFont: TLabel;
    LabelMessageFont: TLabel;
    LabelIconTitleFont: TLabel;
    ButtonUpdate: TButton;
    ButtonMore: TButton;
    ButtonClose: TButton;
    procedure FormCreate(Sender: TObject);
    procedure ButtonUpdateClick(Sender: TObject);
    procedure ButtonMoreClick(Sender: TObject);
    procedure ButtonCloseClick(Sender: TObject);
  private
    { Private declarations }
    procedure UpdateFonts;
  public
    { Public declarations }
  end;

var
  FormMain: TFormMain;

implementation

{$R *.DFM}

procedure TFormMain.UpdateFonts;

  procedure ChangeFontInfo(L: TLabel);

    function FontStyle(F: TFont): string;
    begin
      Result:='';
      with F do
      begin
        if fsBold in Style then Result:=Result+'Bold ';
        if fsItalic in Style then Result:=Result+'Italic ';
        if fsUnderline in Style then Result:=Result+'Underline ';
        if fsStrikeout in Style then Result:=Result+'Strikeout';
      end;
    end;

  begin
    with L,Font do
    begin
      Caption:=Copy(Caption,1,Pos(':',Caption))+' '+Name+' '+IntToStr(Size)+'pt '+FontStyle(Font);
    end;
  end;

begin
  LabelCaptionFont.Font.Assign(SystemFonts.CaptionFont);
  ChangeFontInfo(LabelCaptionFont);
  LabelSmallCaptionFont.Font.Assign(SystemFonts.SmallCaptionFont);
  ChangeFontInfo(LabelSmallCaptionFont);
  LabelMenuFont.Font.Assign(SystemFonts.MenuFont);
  ChangeFontInfo(LabelMenuFont);
  LabelStatusFont.Font.Assign(SystemFonts.StatusFont);
  ChangeFontInfo(LabelStatusFont);
  LabelMessageFont.Font.Assign(SystemFonts.MessageFont);
  ChangeFontInfo(LabelMessageFont);
  LabelIconTitleFont.Font.Assign(SystemFonts.IconTitleFont);
  ChangeFontInfo(LabelIconTitleFont);
end;

procedure TFormMain.FormCreate(Sender: TObject);
begin
  ScaleBy(Abs(SystemFonts.MessageFont.Height),Abs(Font.Height));
  Font.Assign(SystemFonts.MessageFont);
  UpdateFonts;
end;

procedure TFormMain.ButtonUpdateClick(Sender: TObject);
begin
  SystemFonts.Update;
  UpdateFonts;
end;

procedure TFormMain.ButtonMoreClick(Sender: TObject);
begin
  ShellExecute(Handle,'open','http://www.greatis.com/delphicb/systemfonts/',nil,nil,SW_SHOWDEFAULT);
end;

procedure TFormMain.ButtonCloseClick(Sender: TObject);
begin
  Application.Terminate;
end;

end.
